SLSO8Color class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

antique_white → const Color
blue_zodiac → const Color
dark_blue_grey → const Color
dark_peach → const Color
mulled_wine → const Color
opium → const Color
pale_orange → const Color
sunset → const Color